from setuptools import setup,find_namespace_packages, find_packages
import os
from setup_utils import SetupUtils


# Find base directory with reference to setup.py
HERE = SetupUtils.GetHere()
print(f"\033[33mHERE: {HERE}\033[0m")

# Read the version from the VERSION file
VERSION = SetupUtils.GetVersion()
print(f"\033[33mInstalling: {VERSION}\033[0m")

# Read the requirements from the requirements.txt file
DEFAULT_REQUIREMENTS_PATH=os.path.join(HERE,"requirements.txt")
DEFAULT_REQUIREMENTS = SetupUtils.ParseRequirements(DEFAULT_REQUIREMENTS_PATH)
DEFAULT_REQUIREMENTS = SetupUtils.MergeList(DEFAULT_REQUIREMENTS,[
    "pytest",
    "ipykernel",
    "pynvml",
    "nats-py"
])

setup(
    name='gai-lib',
    version=VERSION,
    author="kakkoii1337",
    author_email="kakkoii1337@gmail.com",
    package_dir={'': 'src'},
    #packages=find_namespace_packages(where='src', include=['gai.*']),
    packages=find_packages(where='src'),
    description = "Refer to https://gai-labs.github.io/gai for more information",
    long_description="Refer to https://gai-labs.github.io/gai for more information",
    long_description_content_type="text/markdown",
    classifiers=[
        'Programming Language :: Python :: 3.10',
        "Development Status :: 3 - Alpha",        
        'License :: OSI Approved :: MIT License',
        "Intended Audience :: Science/Research",
        "Intended Audience :: Developers",        
        'Operating System :: OS Independent',
        "Topic :: Software Development",
        "Topic :: Software Development :: Libraries :: Python Modules",        
        "Topic :: Scientific/Engineering :: Artificial Intelligence",        
    ],
    python_requires='>=3.10',
    install_requires=[
        DEFAULT_REQUIREMENTS
    ],
    package_data={
        "gai": [
            "gai.yml"
        ]
    },
    include_package_data=True
)


import os
class SetupUtils:
    # Install local wheel file
    @staticmethod
    def GetWheelFile(name: str,file_path: str) -> str:
        """Returns a path to a local package."""
        file_path=os.path.join(os.getcwd(),"wheels",file_path)
        return f"{name} @ file://{file_path}"

    # Merge two lists and remove duplicates
    @staticmethod
    def MergeList(list1, list2):
        # Ensure both list1 and list2 are lists, default to empty list if None
        list1 = list1 if list1 is not None else []
        list2 = list2 if list2 is not None else []
        return list(set(list1) | set(list2))
    
    @staticmethod
    def ParseRequirements(filepath):
        required=[]
        if os.path.exists(filepath):
            with open(filepath) as f:
                required = f.read().splitlines()
            if not required or len(required)==0:
                raise Exception(f"No requirements found in {filepath}")
            return required
        raise Exception(f"Requirements file not found: {filepath}")
    
    @staticmethod
    def GetHere():
        return os.path.dirname(os.path.abspath(__file__))


    @staticmethod
    def GetVersion():
        version_file = os.path.join(SetupUtils.GetHere(), 'VERSION')
        with open(version_file, 'r') as f:
            return f.read().strip()
